@@ -1,5 +1,5 @@
 ###
-### $Release: 0.7.0 $
+### $Release: 0.8.0 $
 ### copyright(c) 2007-2009 kuwata-lab.com all rights reserved.
 ###
 
@@ -15,9 +15,22 @@ class HtmlHelperTest(unittest.TestCase, TestCaseHelper):
 
     def test_tagattr(self):
         tagattr = tenjin.helpers.html.tagattr
-        self.assertEquals('src="img.png" size="20"', tagattr(src="img.png", size=20))
-        self.assertEquals('',                        tagattr(src='', size=0))
-        self.assertEquals('class="error"',           tagattr(klass='error'))
+        self.assertEquals(' size="20"',     tagattr('size', 20))
+        self.assertEquals('',               tagattr('size', 0))
+        self.assertEquals(' size="large"',  tagattr('size', 20, 'large'))
+        self.assertEquals('',               tagattr('size', 0, 'zero'))
+        self.assertEquals(' title="&lt;&gt;&amp;&quot;"', tagattr('title', '<>&"'))
+        self.assertEquals(' title="<>&""',                tagattr('title', '<>&"', escape=False))
+
+    def test_tagattrs(self):
+        tagattrs = tenjin.helpers.html.tagattrs
+        self.assertEquals(' src="img.png" size="20"', tagattrs(src="img.png", size=20))
+        self.assertEquals('',                         tagattrs(src='', size=0))
+        self.assertEquals(' class="error"',           tagattrs(klass='error'))    # klass='error' => class="error"
+        self.assertEquals(' checked="checked"',       tagattrs(checked='Y'))
+        self.assertEquals(' selected="selected"',     tagattrs(selected=1))
+        self.assertEquals(' disabled="disabled"',     tagattrs(disabled=True))
+        self.assertEquals('',                         tagattrs(checked='', selected=0, disabled=None))
 
     def test_checked(self):
         checked = tenjin.helpers.html.checked
@@ -58,6 +71,21 @@ class HtmlHelperTest(unittest.TestCase, TestCaseHelper):
         self.assertEqual('name="rank" value="A" style="color:red"',
                          nv('rank', 'A', style="color:red"))
 
+    def test_new_cycle(self):
+        cycle = tenjin.helpers.html.new_cycle('odd', 'even')
+        self.assertEqual('odd',  cycle())
+        self.assertEqual('even', cycle())
+        self.assertEqual('odd',  cycle())
+        self.assertEqual('even', cycle())
+        #
+        cycle = tenjin.helpers.html.new_cycle('A', 'B', 'C')
+        self.assertEqual('A', cycle())
+        self.assertEqual('B', cycle())
+        self.assertEqual('C', cycle())
+        self.assertEqual('A', cycle())
+        self.assertEqual('B', cycle())
+        self.assertEqual('C', cycle())
+
 
 remove_unmatched_test_methods(HtmlHelperTest)
 
